==> haskell-wl-pprint-annotated-0.1.0.1-301-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-YgwA6fCfiOBtSZ749ktk2
key:                  wl-pprint-annotated-0.1.0.1-YgwA6fCfiOBtSZ749ktk2
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  82b99956714fcbd5896a78bd78689978
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-YgwA6fCfiOBtSZ749ktk2
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-303-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wl-pprint-annotated
version:              0.1.0.1
visibility:           public
id:                   wl-pprint-annotated-0.1.0.1-L32oYqYI6GC6CWwwy1cyOI
key:                  wl-pprint-annotated-0.1.0.1-L32oYqYI6GC6CWwwy1cyOI
license:              BSD-3-Clause
copyright:            2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
stability:            experimental
homepage:             https://github.com/minad/wl-pprint-annotated#readme
synopsis:             Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.

category:             Text
abi:                  0ca21861a9f65529b5a83dd26068ac7a
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.WL
hidden-modules:       Paths_wl_pprint_annotated
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-annotated
hs-libraries:         HSwl-pprint-annotated-0.1.0.1-L32oYqYI6GC6CWwwy1cyOI
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
